==> google_maps_fleetengine-0.2.0-py3-none-any.whl: google/maps/fleetengine_v1/services/trip_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
)

from google.maps.fleetengine_v1.types import trip_api, trips


class SearchTripsPager:
    """A pager for iterating through ``search_trips`` requests.

    This class thinly wraps an initial
    :class:`google.maps.fleetengine_v1.types.SearchTripsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``trips`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchTrips`` requests and continue to iterate
    through the ``trips`` field on the
    corresponding responses.

    All the usual :class:`google.maps.fleetengine_v1.types.SearchTripsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., trip_api.SearchTripsResponse],
        request: trip_api.SearchTripsRequest,
        response: trip_api.SearchTripsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.maps.fleetengine_v1.types.SearchTripsRequest):
                The initial request object.
            response (google.maps.fleetengine_v1.types.SearchTripsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = trip_api.SearchTripsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[trip_api.SearchTripsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[trips.Trip]:
        for page in self.pages:
            yield from page.trips

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchTripsAsyncPager:
    """A pager for iterating through ``search_trips`` requests.

    This class thinly wraps an initial
    :class:`google.maps.fleetengine_v1.types.SearchTripsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``trips`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchTrips`` requests and continue to iterate
    through the ``trips`` field on the
    corresponding responses.

    All the usual :class:`google.maps.fleetengine_v1.types.SearchTripsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[trip_api.SearchTripsResponse]],
        request: trip_api.SearchTripsRequest,
        response: trip_api.SearchTripsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.maps.fleetengine_v1.types.SearchTripsRequest):
                The initial request object.
            response (google.maps.fleetengine_v1.types.SearchTripsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = trip_api.SearchTripsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[trip_api.SearchTripsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[trips.Trip]:
        async def async_generator():
            async for page in self.pages:
                for response in page.trips:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google_maps_fleetengine-0.2.6-py3-none-any.whl: google/maps/fleetengine_v1/services/trip_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
    Union,
)

from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import retry_async as retries_async

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
    OptionalAsyncRetry = Union[
        retries_async.AsyncRetry, gapic_v1.method._MethodDefault, None
    ]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore
    OptionalAsyncRetry = Union[retries_async.AsyncRetry, object, None]  # type: ignore

from google.maps.fleetengine_v1.types import trip_api, trips


class SearchTripsPager:
    """A pager for iterating through ``search_trips`` requests.

    This class thinly wraps an initial
    :class:`google.maps.fleetengine_v1.types.SearchTripsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``trips`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``SearchTrips`` requests and continue to iterate
    through the ``trips`` field on the
    corresponding responses.

    All the usual :class:`google.maps.fleetengine_v1.types.SearchTripsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., trip_api.SearchTripsResponse],
        request: trip_api.SearchTripsRequest,
        response: trip_api.SearchTripsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.maps.fleetengine_v1.types.SearchTripsRequest):
                The initial request object.
            response (google.maps.fleetengine_v1.types.SearchTripsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.
        """
        self._method = method
        self._request = trip_api.SearchTripsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[trip_api.SearchTripsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[trips.Trip]:
        for page in self.pages:
            yield from page.trips

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class SearchTripsAsyncPager:
    """A pager for iterating through ``search_trips`` requests.

    This class thinly wraps an initial
    :class:`google.maps.fleetengine_v1.types.SearchTripsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``trips`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``SearchTrips`` requests and continue to iterate
    through the ``trips`` field on the
    corresponding responses.

    All the usual :class:`google.maps.fleetengine_v1.types.SearchTripsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[trip_api.SearchTripsResponse]],
        request: trip_api.SearchTripsRequest,
        response: trip_api.SearchTripsResponse,
        *,
        retry: OptionalAsyncRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.maps.fleetengine_v1.types.SearchTripsRequest):
                The initial request object.
            response (google.maps.fleetengine_v1.types.SearchTripsResponse):
                The initial response object.
            retry (google.api_core.retry.AsyncRetry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.
        """
        self._method = method
        self._request = trip_api.SearchTripsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[trip_api.SearchTripsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __aiter__(self) -> AsyncIterator[trips.Trip]:
        async def async_generator():
            async for page in self.pages:
                for response in page.trips:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
